% Sample Script for EEG preprocessing
%% Launch EEGLab and set paths for EEG
% Use the shortcut we created in class, or paste that text here and run it

%% Set some variables for this data set 
readdir = ''; % where we'll look for files ... if not empty, must end in \
writedir = ''; % where we'll write output ... if not empty, must end in \

% Typically take a directory of files to process, but today we'll specify one file
sample_data_file = 'sampleEEGdata.mat';  % Note this is already epoched


%% Import CNT file

% Load file, 
[ALLEEG EEG CURRENTSET ALLCOM] = eeglab; % initialize EEGLab
load([readdir sample_data_file]);  % load this as it is a MAT file.  With EEGlab you and also save as set files and use pop_loadset
eeglab redraw

% Do you have channel locations?  YES!  But assuming you did not....
% Find channel locations using GUI, and then use eegh to get history
% command and create lines of code below to get channel information

% now get channel locations 

% @@@@@@@@@@@@@@@@@@@@@

%% interpolate bad channels using Spherical Spline Interpolation
% If any bad channels exist, then do interpolation, otherwise just get on
% with it!

% We'll make up some bad channels to show how this works
badchan_names = {'P4' 'PO3'};
badchanidx = find(ismember(upper({EEG.chanlocs.labels}'),upper(badchan_names)));

if ~isempty(badchanidx)
    EEG = eeg_interp(EEG,badchanidx,'spherical');
    eeglab redraw
end
    
    
%% Remove channels you don't want -- let's pretend we don't want IZ
EEG = pop_select( EEG,'nochannel',{'IZ'});
eeglab redraw


%% Filter for ERP work

% Note that because it's already epoched, high pass filter with low cut off won't be a good approach here
% in general, filter the continuous data

% Before implementing the filter, use GUI to check OptFIR comparisons

EEG = pop_eegfilt( EEG, 0, 25, [], [0]);  % Low Pass 25 Hz
EEG = eeg_checkset( EEG );
eeglab redraw


% Re-reference the data to average reference
EEG = pop_reref( EEG, []); 
eeglab redraw
% Check number of channels

% How would we re-reference to FPz?  
FPz_idx = find(ismember(upper({EEG.chanlocs.labels}'),upper('FPz')));
EEG = pop_reref( EEG, FPz_idx ); % re-ref to idx channel found above.  Can be more than one channel if you had a set of channels
eeglab redraw
% Check number of channels

% Now re-ref back to average and recover FPz
EEG = pop_reref( EEG, [],'refloc',struct('labels',{'Fpz'},'theta',{0},'radius',{0.50669},'X',{84.9812},'Y',{0},'Z',{-1.786},'sph_theta',{0},'sph_phi',{-1.204},'sph_radius',{85},'type',{''},'urchan',{33},'ref',{'Fpz'},'datachan',{0}));
eeglab redraw
% Check number of channels



%% DO ICA for later artifact removal
% EEG = pop_runica(EEG,'icatype','runica');
% eeglab redraw
%
% Save -- to come back later and keep going
% EEG = pop_saveset( EEG, 'filename',[sample_data_file '.set'],'filepath',writedir);



%% Exercises for class

% Making ERPs and plotting
% * Compute the ERP at each electrode. 
% * Create butterfly plot of all channels, with time as X axis in msec
% * In a new figure, plot only channel Pz
% * Select five time points at which to show topographical plots (e.g., 0 to 400 ms in 100-ms steps). 
% * In one figure, make a series of topographical plots at these time points. 
%   ** To increase the signal-to-noise ratio, make each plot show the average of 
%      activity from 20 ms before until 20 ms after each time point. 
%   ** Indicate the center time point in a title on each subplot. 

% Finding peaks and latencies and plotting
% * Loop through each electrode and find the positive peak time of the ERP between 100 and 400 ms. 
%   ** Store these peak times in a separate variable and then make a topographical plot of the 
%       peak times (that is, the topographical map will illustrate times in milliseconds, 
%       not activity at  peak times). 
%   ** Include a color bar in the figure and make sure to show times in milliseconds from 
%       time 0 (not, for example, time in milliseconds since 100 ms or indices instead of milliseconds).
% * Describe what you see: What areas of the scalp show the earliest and the latest peak responses to 
%    the stimulus within this window?