function [sine_wave, t] = make_sin(f, hz, varargin);
% function make_sin
%
% usage:  
%    [sine_wave, t] = make_sin(f, hz, anyvalue); 
%           -- returns sine_wave, timebase and gives a plot
%    [sine_wave] = make_sin(f, hz)
%           -- returns sine wave of freq f at sample rate hz
%    [sine_wave] = make_sin(f) 
%           -- minimum specification, returns sine wave of freq f at 100 hz
% 
% pass frequency (f) and sample rate (hz) to the function, 
% and it returns a one second sine wave of that frequency at that sample
% rate
% 
% if you give it any third argument, you get a plot (for free!)
%
% John JB Allen, 17 June 2011 (made for GeekSquad)

if nargin < 1
    doc make_sin;
    sine_wave = [];
    t = [];
elseif nargin < 2
    hz = 100;
end
if nargin > 0
    t=1/hz:1/hz:1; % make time base
    sine_wave = sin(2*pi*f*t);
    if nargin > 2 % if you offer any third argument, you get a plot!
        plot(t,sine_wave);
    end
end